==> qtjambi-qml-debuginfo-macos-5.15.20.jar: sources/QtJambiQml/QQmlScriptString_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQml/qqmlscriptstring.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQml/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQmlScriptString(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlScriptString")
    QQmlScriptString *_ptr = reinterpret_cast<QQmlScriptString *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QQmlScriptString()
void __qt_construct_QQmlScriptString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlScriptString()")
    Q_UNUSED(__java_arguments)
    QQmlScriptString *__qt_this = new(__qtjambi_ptr) QQmlScriptString();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QQmlScriptString::QQmlScriptString()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_initialize_1native__Lio_qt_qml_QQmlScriptString_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlScriptString::QQmlScriptString()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlScriptString, sizeof(QQmlScriptString), typeid(QQmlScriptString), false, &deleter_QQmlScriptString, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QQmlScriptString(QQmlScriptString)
void __qt_construct_QQmlScriptString_cref_QQmlScriptString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlScriptString(QQmlScriptString)")
    jobject arg__1 = __java_arguments[0].l;
    const QQmlScriptString& __qt_arg__1 = qtjambi_cast<const QQmlScriptString& >(__jni_env, arg__1);
    QQmlScriptString *__qt_this = new(__qtjambi_ptr) QQmlScriptString(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QQmlScriptString::QQmlScriptString(QQmlScriptString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_initialize_1native__Lio_qt_qml_QQmlScriptString_2Lio_qt_qml_QQmlScriptString_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlScriptString::QQmlScriptString(QQmlScriptString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlScriptString_cref_QQmlScriptString, sizeof(QQmlScriptString), typeid(QQmlScriptString), false, &deleter_QQmlScriptString, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlScriptString
void __qt_destruct_QQmlScriptString(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlScriptString")
    reinterpret_cast<QQmlScriptString*>(ptr)->~QQmlScriptString();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlScriptString::booleanLiteral(bool*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_booleanLiteral_1native_1bool_1ptr_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::booleanLiteral(bool*)const", __qt_this)
        bool ok(false);
        bool* __qt_ok0 = &ok;
        bool __qt_return_value = __qt_this->booleanLiteral(__qt_ok0);
        __java_return_value = ok ? QtJambiAPI::toJavaBooleanObject(__jni_env, __qt_return_value) : nullptr;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlScriptString::isEmpty()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_isEmpty_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::isEmpty()const", __qt_this)
        __java_return_value = __qt_this->isEmpty();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlScriptString::isNullLiteral()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_isNullLiteral_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::isNullLiteral()const", __qt_this)
        __java_return_value = __qt_this->isNullLiteral();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlScriptString::isUndefinedLiteral()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_isUndefinedLiteral_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::isUndefinedLiteral()const", __qt_this)
        __java_return_value = __qt_this->isUndefinedLiteral();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlScriptString::numberLiteral(bool*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_numberLiteral_1native_1bool_1ptr_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::numberLiteral(bool*)const", __qt_this)
        bool ok(false);
        bool* __qt_ok0 = &ok;
        qreal __qt_return_value = __qt_this->numberLiteral(__qt_ok0);
        __java_return_value = ok ? QtJambiAPI::toJavaDoubleObject(__jni_env, __qt_return_value) : nullptr;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlScriptString::operator=(QQmlScriptString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_assign_1native_1cref_1QQmlScriptString__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::operator=(QQmlScriptString)", __qt_this)
        const QQmlScriptString& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QQmlScriptString>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlScriptString::operator==(QQmlScriptString)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_equals_1native_1cref_1QQmlScriptString_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::operator==(QQmlScriptString)const", __qt_this)
        const QQmlScriptString& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QQmlScriptString>(arg__1);
        __java_return_value = (*__qt_this) == __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlScriptString::stringLiteral()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_stringLiteral_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::stringLiteral()const", __qt_this)
        QString __qt_return_value = __qt_this->stringLiteral();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QQmlScriptString(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QQmlScriptString>("QQmlScriptString", "io/qt/qml/QQmlScriptString");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QQmlScriptString, {
        ConstructorInfo(&__qt_construct_QQmlScriptString, nullptr)
       ,ConstructorInfo(&__qt_construct_QQmlScriptString_cref_QQmlScriptString, "Lio/qt/qml/QQmlScriptString;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlScriptString);
    registerMetaType<QQmlScriptString>("QQmlScriptString");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.5.4.jar: sources/QtJambiQml/QQmlScriptString_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQml/qqmlscriptstring.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQml/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQmlScriptString(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlScriptString")
    QQmlScriptString *_ptr = reinterpret_cast<QQmlScriptString *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QQmlScriptString()
void __qt_construct_QQmlScriptString_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlScriptString()")
    Q_UNUSED(__java_arguments)
    QQmlScriptString *__qt_this = new(__qtjambi_ptr) QQmlScriptString();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QQmlScriptString(QQmlScriptString)
void __qt_construct_QQmlScriptString_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlScriptString(QQmlScriptString)")
    jobject arg__1 = __java_arguments[0].l;
    const QQmlScriptString& __qt_arg__1 = qtjambi_cast<const QQmlScriptString& >(__jni_env, arg__1);
    QQmlScriptString *__qt_this = new(__qtjambi_ptr) QQmlScriptString(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QQmlScriptString
void __qt_destruct_QQmlScriptString(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlScriptString")
    reinterpret_cast<QQmlScriptString*>(ptr)->~QQmlScriptString();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlScriptString::QQmlScriptString()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_initialize_1native__Lio_qt_qml_QQmlScriptString_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlScriptString::QQmlScriptString()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlScriptString_0, sizeof(QQmlScriptString), typeid(QQmlScriptString), false, &deleter_QQmlScriptString, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlScriptString::QQmlScriptString(QQmlScriptString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_initialize_1native__Lio_qt_qml_QQmlScriptString_2Lio_qt_qml_QQmlScriptString_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlScriptString::QQmlScriptString(QQmlScriptString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlScriptString_1, sizeof(QQmlScriptString), typeid(QQmlScriptString), false, &deleter_QQmlScriptString, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlScriptString::booleanLiteral(bool*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_booleanLiteral_1native_1bool_1ptr_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::booleanLiteral(bool*)const", __qt_this)
        bool ok(false);
        bool* __qt_ok0 = &ok;
        bool __qt_return_value = __qt_this->booleanLiteral(__qt_ok0);
        __java_return_value = ok ? QtJambiAPI::toJavaBooleanObject(__jni_env, __qt_return_value) : nullptr;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlScriptString::isEmpty()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_isEmpty_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::isEmpty()const", __qt_this)
        __java_return_value = __qt_this->isEmpty();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlScriptString::isNullLiteral()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_isNullLiteral_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::isNullLiteral()const", __qt_this)
        __java_return_value = __qt_this->isNullLiteral();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlScriptString::isUndefinedLiteral()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_isUndefinedLiteral_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::isUndefinedLiteral()const", __qt_this)
        __java_return_value = __qt_this->isUndefinedLiteral();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlScriptString::numberLiteral(bool*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_numberLiteral_1native_1bool_1ptr_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::numberLiteral(bool*)const", __qt_this)
        bool ok(false);
        bool* __qt_ok0 = &ok;
        qreal __qt_return_value = __qt_this->numberLiteral(__qt_ok0);
        __java_return_value = ok ? QtJambiAPI::toJavaDoubleObject(__jni_env, __qt_return_value) : nullptr;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlScriptString::operator=(QQmlScriptString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_assign_1native_1cref_1QQmlScriptString__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::operator=(QQmlScriptString)", __qt_this)
        const QQmlScriptString& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QQmlScriptString>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlScriptString::operator==(QQmlScriptString)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_equals_1native_1cref_1QQmlScriptString_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::operator==(QQmlScriptString)const", __qt_this)
        const QQmlScriptString& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QQmlScriptString>(arg__1);
        __java_return_value = (*__qt_this) == __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlScriptString::stringLiteral()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_stringLiteral_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlScriptString::stringLiteral()const", __qt_this)
        QString __qt_return_value = __qt_this->stringLiteral();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlScriptString_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QQmlScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QQmlScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QQmlScriptString(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QQmlScriptString>("QQmlScriptString", "io/qt/qml/QQmlScriptString");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QQmlScriptString, {
        ConstructorInfo(&__qt_construct_QQmlScriptString_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QQmlScriptString_1, "Lio/qt/qml/QQmlScriptString;")
    });
// END: function table

    registerMetaObject(typeId, QQmlScriptString::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlScriptString);
    registerMetaType<QQmlScriptString>("QQmlScriptString");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
